@@ -1,5 +1,5 @@
 (*
- * Copyright 2003-2009 Savonet team
+ * Copyright 2003-2016 Savonet team
  *
  * This file is part of Ocaml-cry.
  *
@@ -33,6 +33,20 @@
 
 (** {2 Types and errors} *)
 
+type operation = [`Read|`Write|`Both]
+
+type transport = {
+  write: Bytes.t -> int -> int -> int;
+  read: Bytes.t -> int -> int -> int;
+  wait_for : operation -> float -> bool;
+  close: unit -> unit
+}
+
+(** Optional ssl module *)
+
+(** Register a transport module to be used for SSL connections. *)
+val register_ssl : (?bind:string -> host:string -> Unix.sockaddr -> transport) -> unit 
+
 (** Possible errors. *)
 type error =
   | Create of exn
@@ -41,8 +55,10 @@ type error =
   | Write of exn
   | Read of exn
   | Busy 
+  | Ssl_unavailable
   | Not_connected
   | Invalid_usage
+  | Unknown_host of string
   | Bad_answer of string option 
   | Http_answer of int*string*string
 
@@ -51,13 +67,17 @@ exception Error of error
 (** Get a string explaining an error. *)
 val string_of_error : exn -> string
 
+(** Possible verbs for HTTP streaming. Default: [Source] *)
+type verb = Put | Post | Source
+
 (** Possible protocols. [Icy] is the (undocumented) shoutcast source protocol.
   * [Http] is the icecast2 source protocol. 
+  * [Https] is the icecast2 source protocol with TLS connection.
   * 
   * Ogg streaming is only possible with [Http]. Any headerless format,
   * (e.g. mpeg containers), should work with both protocols,
   * provided you set the correct content-type (mime) for the source. *)
-type protocol = Icy | Http
+type protocol = Icy | Http of verb | Https of verb
 
 (** Return a string representation of a protocol. *)
 val string_of_protocol : protocol -> string
@@ -83,17 +103,24 @@ val content_type_of_string : string -> content_type
 (** Get the string representation of a mime type. *)
 val string_of_content_type : content_type -> string
 
+(** Type for a mount point. [Icy_id] are for Shoutcast v2
+  * sid. For Shoutcast v1, use [Icy_id 1]. *)
+type mount =
+  | Icy_id of int
+  | Icecast_mount of string
+
 (** Type for a source connection. 
   *
   * [headers] is a hash table containing the headers.
   * See [connection] function for more details. *)
 type connection =
   {
-    mount        : string;
+    mount        : mount;
     user         : string;
     password     : string;
     host         : string;
     port         : int;
+    chunked      : bool;
     content_type : content_type;
     protocol     : protocol;
     headers      : (string, string) Hashtbl.t
@@ -111,11 +138,11 @@ type metadata = (string,string) Hashtbl.t
 
 (* Type for connection data *)
 type connection_data =
-  { connection      : connection;
-    data_socket     : Unix.file_descr }
+  { connection : connection;
+    transport  : transport }
 
 (** Type for the status of a handler. *)
-type status = Connected of connection_data | Disconnected 
+type status = Connected of connection_data | Disconnected
 
 (** Type for the main handler. *)
 type t
@@ -124,11 +151,9 @@ type t
 
 (** Create a new handler.
   * 
-  * [ipv6] is [false] by default.
   * [bind] is not used by default (system default). 
   * [timeout] is [30.] by default. *)
 val create :
-  ?ipv6:bool ->
   ?bind:string ->
   ?connection_timeout:float -> 
   ?timeout:float -> unit -> t
@@ -142,7 +167,7 @@ val get_status : t -> status
 val get_icy_cap : t -> bool
 
 (** Get data associated with a connection. Use it only if you know
-  * what you are doing. 
+  * what you are doing.
   *
   * Raises: [Error Not_connected] if not connected. *)
 val get_connection_data : t -> connection_data
@@ -159,12 +184,18 @@ val audio_info :
 (** Create a new [connection] value
   * with default values. 
   *
+  * [mount] is mandatory when using the [Http] protocol.
+  * [icy_id] is mandatory to support multiple shoutcast sources
+  * on shoutcast v2.
+  *
   * [host] is ["localhost"] by default.
   * [password] is ["hackme"] by default.
   * [user] is ["source"] by default. Change [user] only if you know
   * what your are doing.
   * [protocol] is [Http] by default.
   * [port] is [8000] by default.
+  * [chunked] is [false] by default and only works with HTTP/1.1-capable
+  * servers.
   * 
   * The list of preset headers for [Http] connections is:
   * ["User-Agent"], ["ice-name"], ["ice-genre"],
@@ -188,10 +219,11 @@ val connection :
   ?description:string ->
   ?host:string ->
   ?port:int ->
+  ?chunked:bool ->
   ?password:string ->
   ?protocol:protocol ->
   ?user:string ->
-  mount:string -> 
+  mount:mount ->
   content_type:content_type -> 
   unit -> connection
 
@@ -220,11 +252,11 @@ val manual_update_metadata :
            protocol:protocol ->
            user:string ->
            password:string ->
-           mount:string ->
+           mount:mount ->
            ?connection_timeout:float ->
            ?timeout:float ->
            ?headers:(string, string) Hashtbl.t ->
-           ?ipv6:bool -> ?bind:string ->
+           ?bind:string ->
            ?charset:string -> metadata -> 
            unit
 
