@@ -29,7 +29,7 @@ type transport = {
 
 let register _ = ()
 
-(*
+
 let () =
   Ssl_threads.init ();
   Ssl.init ()
@@ -40,9 +40,14 @@ let register fn =
     (* SSL_VERIFY_NONE is default in shout. TODO: add option.. *)
     Ssl.set_verify ctx [] (Some Ssl.client_verify_callback);
     Ssl.set_verify_depth ctx 3;
+    Ssl.set_default_verify_paths ctx;
     let ssl =
       Ssl.open_connection_with_context ctx socketaddr
     in
+    let shutdown () =
+      Ssl.shutdown ssl;
+      Unix.close (Ssl.file_descr_of_socket ssl)
+    in
     begin try
      match bind with
        | None -> ()
@@ -54,7 +59,7 @@ let register fn =
           Unix.bind socket bind_addr ;
     with e ->
       begin try
-        Ssl.shutdown ssl
+        shutdown()
       with _ -> () end;
       raise e
     end;
@@ -78,10 +83,10 @@ let register fn =
     {ssl_write = Ssl.write ssl;
      ssl_read = Ssl.read ssl;
      ssl_wait_for = wait_for;
-     ssl_close = (fun () -> Ssl.shutdown ssl) }
+     ssl_close = shutdown }
   in
   fn connect_ssl
-*)
+
 
 (*
 let register fn =
